@@ -20,7 +20,7 @@ my %known_bad_locales = (   # XXX eventually will need version info if and
     solaris => [ 'vi_VN.UTF-8', ],  # Use of U+A8 segfaults: GH #20578
 );
 
-eval { require POSIX; import POSIX 'locale_h'; };
+eval { require POSIX; POSIX->import('locale_h'); };
 my $has_locale_h = ! $@;
 
 my @known_categories = ( qw(LC_ALL LC_COLLATE LC_CTYPE LC_MESSAGES LC_MONETARY
@@ -312,9 +312,6 @@ sub _decode_encodings { # For use only by other functions in this file!
 	    push @enc, $_;
             push @enc, "$_.UTF-8";
             push @enc, "$_.65001"; # Windows UTF-8
-            push @enc, "$_.ACP"; # Windows ANSI code page
-            push @enc, "$_.OCP"; # Windows OEM code page
-            push @enc, "$_.1252"; # Windows
 	}
     }
     if ($^O eq 'os390') {
@@ -322,6 +319,7 @@ sub _decode_encodings { # For use only by other functions in this file!
     }
     push @enc, "UTF-8";
     push @enc, "65001"; # Windows UTF-8
+    push @enc, "1252";  # Windows
 
     return @enc;
 }
@@ -570,8 +568,10 @@ sub find_locales ($;$) {
         # Other subversive stuff.
         delete local @ENV{qw(IFS CDPATH ENV BASH_ENV)};
 
-        if (-x "/usr/bin/locale"
-            && open(LOCALES, '-|', "/usr/bin/locale -a 2>/dev/null"))
+        my $locale_cmd = "/usr/bin/locale";
+        $locale_cmd = "/bin/locale" unless -x $locale_cmd;
+        if (   -x $locale_cmd
+            && open(LOCALES, '-|', "$locale_cmd -a 2>/dev/null"))
         {
             while (<LOCALES>) {
 
@@ -634,6 +634,11 @@ sub find_locales ($;$) {
             state @my_data = <DATA>; close DATA if fileno DATA;
             push @Data, @my_data;
 
+            foreach my $default (qw(.ACP .OCP)) {
+                _trylocale($default, \@categories, \@Locale,
+                           $allow_incompatible);
+            }
+
             foreach my $line (@Data) {
                 chomp $line;
                 my ($locale_name, $language_codes, $country_codes, $encodings) =
